)]}'
{
  "log": [
    {
      "commit": "d4faaecbcc6d9ea4f7c05f6de6af98e2336a4afb",
      "tree": "20ce6e4991c0dc3b0701fbb0b37819f19d3e9d00",
      "parents": [
        "9ce768ead83216d394175c0a0d72bc527648c7d0"
      ],
      "author": {
        "name": "David S. Miller",
        "email": "davem@sunset.davemloft.net",
        "time": "Thu Oct 11 22:15:08 2007 -0700"
      },
      "committer": {
        "name": "David S. Miller",
        "email": "davem@sunset.davemloft.net",
        "time": "Thu Oct 11 22:17:20 2007 -0700"
      },
      "message": "[ZLIB]: Fix external builds of zlib_inflate code.\n\nMove zlib_inflate_blob() out into it\u0027s own source file,\ninfutil.c, so that things like the powerpc zImage builder\nin arch/powerpc/boot/Makefile don\u0027t end up trying to\ncompile it.\n\nSigned-off-by: David S. Miller \u003cdavem@davemloft.net\u003e\n"
    },
    {
      "commit": "4f3865fb57a04db7cca068fed1c15badc064a302",
      "tree": "4c923c72b6ac9b633c87cc73b55a75c7cfd0f044",
      "parents": [
        "4f1bcaf094ccc512c23e10104c05a6f8e5b7a9e4"
      ],
      "author": {
        "name": "Richard Purdie",
        "email": "rpurdie@rpsys.net",
        "time": "Thu Jun 22 14:47:34 2006 -0700"
      },
      "committer": {
        "name": "Linus Torvalds",
        "email": "torvalds@g5.osdl.org",
        "time": "Thu Jun 22 15:05:58 2006 -0700"
      },
      "message": "[PATCH] zlib_inflate: Upgrade library code to a recent version\n\nUpgrade the zlib_inflate implementation in the kernel from a patched\nversion 1.1.3/4 to a patched 1.2.3.\n\nThe code in the kernel is about seven years old and I noticed that the\nexternal zlib library\u0027s inflate performance was significantly faster (~50%)\nthan the code in the kernel on ARM (and faster again on x86_32).\n\nFor comparison the newer deflate code is 20% slower on ARM and 50% slower\non x86_32 but gives an approx 1% compression ratio improvement.  I don\u0027t\nconsider this to be an improvement for kernel use so have no plans to\nchange the zlib_deflate code.\n\nVarious changes have been made to the zlib code in the kernel, the most\nsignificant being the extra functions/flush option used by ppp_deflate.\nThis update reimplements the features PPP needs to ensure it continues to\nwork.\n\nThis code has been tested on ARM under both JFFS2 (with zlib compression\nenabled) and ppp_deflate and on x86_32.  JFFS2 sees an approx.  10% real\nworld file read speed improvement.\n\nThis patch also removes ZLIB_VERSION as it no longer has a correct value.\nWe don\u0027t need version checks anyway as the kernel\u0027s module handling will\ntake care of that for us.  This removal is also more in keeping with the\nzlib author\u0027s wishes (http://www.zlib.net/zlib_faq.html#faq24) and I\u0027ve\nadded something to the zlib.h header to note its a modified version.\n\nSigned-off-by: Richard Purdie \u003crpurdie@rpsys.net\u003e\nAcked-by: Joern Engel \u003cjoern@wh.fh-wedel.de\u003e\nSigned-off-by: Andrew Morton \u003cakpm@osdl.org\u003e\nSigned-off-by: Linus Torvalds \u003ctorvalds@osdl.org\u003e\n"
    },
    {
      "commit": "1da177e4c3f41524e886b7f1b8a0c1fc7321cac2",
      "tree": "0bba044c4ce775e45a88a51686b5d9f90697ea9d",
      "parents": [],
      "author": {
        "name": "Linus Torvalds",
        "email": "torvalds@ppc970.osdl.org",
        "time": "Sat Apr 16 15:20:36 2005 -0700"
      },
      "committer": {
        "name": "Linus Torvalds",
        "email": "torvalds@ppc970.osdl.org",
        "time": "Sat Apr 16 15:20:36 2005 -0700"
      },
      "message": "Linux-2.6.12-rc2\n\nInitial git repository build. I\u0027m not bothering with the full history,\neven though we have it. We can create a separate \"historical\" git\narchive of that later if we want to, and in the meantime it\u0027s about\n3.2GB when imported into git - space that would just make the early\ngit days unnecessarily complicated, when we don\u0027t have a lot of good\ninfrastructure for it.\n\nLet it rip!\n"
    }
  ]
}
